
/* Probe Designer single-probe stylesheet */

#main {
	padding-top: 1em;
}

#title {
	font-family: "Lobster";
	font-size: 5em;
	text-align: center;
}

#description {
	margin: 2em 0;
	font-size: 1.4em;
	line-height: 2em;
	text-align: center;
}

/* TABS */

.nav.nav-tabs {
	font-size: 1.5em;
	font-weight: bold;
}

.tab-content {
	padding: 1em;
	font-size: 1.2em;
}
