html, body {
	padding-bottom: 3.5em;
}

#footer {
	position: fixed;
	bottom: 0;

	margin-top: 1.5em;
	padding: 0.5em;

	background-color: white;
	border-top: 1px solid #bababa;

	text-align: center;
}
