
<div class="row">
	<div id="footer" class="col col-md-8 offset-md-2 col-sm-12">
		FISH ProDe v1.1.0 - &copy; Gabriele Girelli 2016-18 - <a href="https://ggirelli.github.io/fish-prode/" target='_new' data-toggle="tooltip" data-placement="top" title="Read the documentation!">Need help?</a>
	</div>
</div>

<script type="text/javascript">
$(function () {

	// Enable tooltips
	$('[data-toggle="tooltip"]').tooltip()

})
</script>

</body>
</html>
